name = "SeisSrcInv"
__version__ = "0.2"
__description__ = "SeisSrcInv - A full waveform seismic source mechanism inversion package"
__license__ = "MIT"
__author__ = "Tom Hudson"
__email__ = "tsh37@alumni.cam.ac.uk"
import SeisSrcInv.inversion
import SeisSrcInv.plot
